import sys

def adding(x, y):
    return x + y

def main():
    if len(sys.argv) != 3:
        print("Please provide two numbers as command-line arguments.")
    else:
        x = int(sys.argv[1])
        y = int(sys.argv[2])
        result = adding(x, y)
        print(f"Sum of {x} and {y} is {result}")

if __name__ == "__main__":
    main()



import pytest
from satyampy import __main__

# class TestSatyampy(unittest.TestCase):
def test_adding(sample_inputs):
    x, y = sample_inputs
    assert __main__.adding(x, y) == 5
    # self.assertEqual(__main__.adding(2, 3), 5)
    # self.assertEqual(__main__.adding(-1, 1), 0)
    # self.assertEqual(__main__.adding(0, 0), 0)
        # Add more test cases as needed

# if __name__ == '__main__':
#     unittest.main()



from setuptools import setup, find_packages

setup(
    name='satyampy',
    version='0.1.2',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'satyampy = satyampy.__main__:main'
        ]
    },
)
